@@ -41,49 +41,74 @@ show_rlimits_generic (void)
 	show_limit (RLIMIT_STACK);
 }
 
-#if !defined (PROCENV_PLATFORM_DARWIN)
-
 void
 show_clocks_generic (void)
 {
-	show_clock_res (CLOCK_REALTIME);
-
-#if defined CLOCK_REALTIME_COARSE
-	show_clock_res (CLOCK_REALTIME_COARSE);
-#endif
-
-#if defined CLOCK_REALTIME_HR
-	show_clock_res (CLOCK_REALTIME_HR);
-#endif
-
-	show_clock_res (CLOCK_MONOTONIC);
-
-#if defined CLOCK_MONOTONIC_COARSE
-	show_clock_res (CLOCK_MONOTONIC_COARSE);
-#endif
-
-#if defined CLOCK_MONOTONIC_RAW
-	show_clock_res (CLOCK_MONOTONIC_RAW);
-#endif
-
-#if defined (PROCENV_PLATFORM_LINUX) || defined (PROCENV_PLATFORM_HURD)
-
-	show_clock_res (CLOCK_PROCESS_CPUTIME_ID);
-	show_clock_res (CLOCK_THREAD_CPUTIME_ID);
-#if defined CLOCK_BOOTTIME
+#ifdef CLOCK_BOOTTIME
 	show_clock_res (CLOCK_BOOTTIME);
 #endif
 
+#ifdef CLOCK_BOOTTIME_ALARM
+	show_clock_res (CLOCK_BOOTTIME_ALARM);
 #endif
 
-#if defined CLOCK_TAI
+#ifdef CLOCK_MONOTONIC
+	show_clock_res (CLOCK_MONOTONIC);
+#endif
+
+#ifdef CLOCK_MONOTONIC_COARSE
+	show_clock_res (CLOCK_MONOTONIC_COARSE);
+#endif
+
+#ifdef CLOCK_MONOTONIC_RAW
+	show_clock_res (CLOCK_MONOTONIC_RAW);
+#endif
+
+#ifdef CLOCK_MONOTONIC_RAW_APPROX
+	show_clock_res (CLOCK_MONOTONIC_RAW_APPROX);
+#endif
+
+#ifdef CLOCK_PROCESS_CPUTIME_ID
+	show_clock_res (CLOCK_PROCESS_CPUTIME_ID);
+#endif
+
+#ifdef CLOCK_REALTIME
+	show_clock_res (CLOCK_REALTIME);
+#endif
+
+#ifdef CLOCK_REALTIME_ALARM
+	show_clock_res (CLOCK_REALTIME_ALARM);
+#endif
+
+#ifdef CLOCK_REALTIME_COARSE
+	show_clock_res (CLOCK_REALTIME_COARSE);
+#endif
+
+#ifdef CLOCK_REALTIME_HR
+	show_clock_res (CLOCK_REALTIME_HR);
+#endif
+
+#ifdef CLOCK_TAI
 	show_clock_res (CLOCK_TAI);
 #endif
 
-}
-
+#ifdef CLOCK_PROCESS_CPUTIME_ID
+	show_clock_res (CLOCK_PROCESS_CPUTIME_ID);
 #endif
 
+#ifdef CLOCK_THREAD_CPUTIME_ID
+	show_clock_res (CLOCK_THREAD_CPUTIME_ID);
+#endif
+
+#ifdef CLOCK_UPTIME_RAW
+	show_clock_res (CLOCK_UPTIME_RAW);
+#endif
+
+#ifdef CLOCK_UPTIME_RAW_APPROX
+	show_clock_res (CLOCK_UPTIME_RAW_APPROX);
+#endif
+}
+
 long
 get_kernel_bits_generic (void)
 {
@@ -1061,3 +1086,22 @@ show_mounts_generic_linux (ShowMountType what)
 }
 
 #endif /* PROCENV_PLATFORM_LINUX || PROCENV_PLATFORM_HURD */
+
+#if defined (PROCENV_PLATFORM_LINUX) || defined (PROCENV_PLATFORM_BSD) || defined (PROCENV_PLATFORM_DARWIN)
+
+void
+show_timezone_generic (void)
+{
+	tzset ();
+
+	entry ("tzname[0]", "'%s'", tzname[0]);
+	entry ("tzname[1]", "'%s'", tzname[1]);
+
+	entry ("timezone", "%ld", timezone);
+
+#ifndef PROCENV_PLATFORM_BSD
+	entry ("daylight", "%d", daylight);
+#endif
+}
+
+#endif
